@@ -1,11 +1,9 @@
-#from django.core.mail import send_mail
-#from email_html.mail import send_mail 
-from mail_templated import send_mail
 from django.core.management.base import BaseCommand, CommandError
 from django.conf import settings
 from django.contrib.auth.models import User
 from django.template.loader import render_to_string
 
+from mail_templated import send_mail
 from optparse import make_option
 import datetime
 
@@ -42,7 +40,7 @@ class Command(BaseCommand):
 
     help = '''Find users who have signed up within the past X minutes (default 60) and email them.
 
-Define your email templates in **TEMPALTE_DIR**/email/welcome_subject.html and **TEMPALTE_DIR**/email/welcome_body.html
+Define your email templates in **TEMPALTE_DIR**/email/welcome.tpl and **TEMPALTE_DIR**/email/notify.tpl
 
 You must also define your WELCOME_FROM_EMAIL and NOTIFICATION_TO_EMAIL in your settings file.
 
@@ -67,8 +65,6 @@ EXAMPLE:
 			new_users = [new_users[0]]
 
 		for user in new_users:
-			subject = render_to_string("email/welcome_subject.html", {'user': user})
-			body = render_to_string("email/welcome_body.html", {'user': user})
 
 			if verbose:
 				print "Welcoming " +  str(user.username) + ' (' + str(user.email) + ').'
@@ -90,9 +86,6 @@ EXAMPLE:
 
 			num_new_users = str(len(new_users))
 
-			notify_subject = render_to_string("email/notify_subject.html", {'num_new_users': num_new_users})
-			notify_body = render_to_string("email/notify_body.html", {'new_users': new_users})
-
 			if verbose:
 				print 'Sending notification of ' + num_new_users + ' new users to ' + settings.NOTIFICATION_TO_EMAIL + '.'
 
